pub struct AnalyzedExportOp {
pub name: String,
pub input: AnalyzedLocalCollectorReference,
pub export_target_factory: Arc<dyn TargetFactory + Send + Sync>,
pub export_context: Arc<dyn Any + Send + Sync>,
pub primary_key_def: AnalyzedPrimaryKeyDef,
pub primary_key_schema: Box<[FieldSchema]>,
pub value_fields: Vec<u32>,
pub value_stable: bool,
pub output_value_fingerprinter: Fingerprinter,
pub def_fp: FieldDefFingerprint,
}Fields
name: Stringinput: AnalyzedLocalCollectorReferenceexport_target_factory: Arc<dyn TargetFactory + Send + Sync>export_context: Arc<dyn Any + Send + Sync>primary_key_def: AnalyzedPrimaryKeyDefprimary_key_schema: Box<[FieldSchema]>value_fields: Vec<u32>idx for value fields - excluding the primary key field.
value_stable: boolIf true, value is never changed on the same primary key. This is guaranteed if the primary key contains auto-generated UUIDs.
output_value_fingerprinter: FingerprinterFingerprinter of the output value.
def_fp: FieldDefFingerprintAuto Trait Implementations
impl !RefUnwindSafe for AnalyzedExportOp
impl !UnwindSafe for AnalyzedExportOp
impl Freeze for AnalyzedExportOp
impl Send for AnalyzedExportOp
impl Sync for AnalyzedExportOp
impl Unpin for AnalyzedExportOp
impl UnsafeUnpin for AnalyzedExportOp