pub struct PartialSourceRow {
pub key: KeyValue,
pub key_aux_info: Value,
pub data: PartialSourceRowData,
}Fields
key: KeyValuekey_aux_info: ValueAuxiliary information for the source row, to be used when reading the content. e.g. it can be used to uniquely identify version of the row. Use serde_json::Value::Null to represent no auxiliary information.
data: PartialSourceRowDataAuto Trait Implementations
impl Freeze for PartialSourceRow
impl RefUnwindSafe for PartialSourceRow
impl Send for PartialSourceRow
impl Sync for PartialSourceRow
impl Unpin for PartialSourceRow
impl UnsafeUnpin for PartialSourceRow
impl UnwindSafe for PartialSourceRow