Hash

Trait Hash 

1.0.0 · Source
pub trait Hash {
    // Required method
    fn hash<H>(&self, state: &mut H)
       where H: Hasher;

    // Provided method
    fn hash_slice<H>(data: &[Self], state: &mut H)
       where H: Hasher,
             Self: Sized { ... }
}
A hashable type.

Types implementing Hash are able to be hashed with an instance of Hasher.

Implementing Hash

You can derive Hash with #[derive(Hash)] if all fields implement Hash. The resulting hash will be the combination of the values from calling hash on each field.

#[derive(Hash)]
struct Rustacean {
    name: String,
    country: String,
}

If you need more control over how a value is hashed, you can of course implement the Hash trait yourself:

use std::hash::{Hash, Hasher};

struct Person {
    id: u32,
    name: String,
    phone: u64,
}

impl Hash for Person {
    fn hash<H: Hasher>(&self, state: &mut H) {
        self.id.hash(state);
        self.phone.hash(state);
    }
}

Hash and Eq

When implementing both Hash and Eq, it is important that the following property holds:

k1 == k2 -> hash(k1) == hash(k2)

In other words, if two keys are equal, their hashes must also be equal. HashMap and HashSet both rely on this behavior.

Thankfully, you won’t need to worry about upholding this property when deriving both Eq and Hash with #[derive(PartialEq, Eq, Hash)].

Violating this property is a logic error. The behavior resulting from a logic error is not specified, but users of the trait must ensure that such logic errors do not result in undefined behavior. This means that unsafe code must not rely on the correctness of these methods.

Prefix collisions

Implementations of hash should ensure that the data they pass to the Hasher are prefix-free. That is, values which are not equal should cause two different sequences of values to be written, and neither of the two sequences should be a prefix of the other.

For example, the standard implementation of Hash for &str passes an extra 0xFF byte to the Hasher so that the values ("ab", "c") and ("a", "bc") hash differently.

Portability

Due to differences in endianness and type sizes, data fed by Hash to a Hasher should not be considered portable across platforms. Additionally the data passed by most standard library types should not be considered stable between compiler versions.

This means tests shouldn’t probe hard-coded hash values or data fed to a Hasher and instead should check consistency with Eq.

Serialization formats intended to be portable between platforms or compiler versions should either avoid encoding hashes or only rely on Hash and Hasher implementations that provide additional guarantees.

Required Methods

1.0.0 · Source

fn hash<H>(&self, state: &mut H)
where H: Hasher,

Feeds this value into the given Hasher.

Examples
use std::hash::{DefaultHasher, Hash, Hasher};

let mut hasher = DefaultHasher::new();
7920.hash(&mut hasher);
println!("Hash is {:x}!", hasher.finish());

Provided Methods

1.3.0 · Source

fn hash_slice<H>(data: &[Self], state: &mut H)
where H: Hasher, Self: Sized,

Feeds a slice of this type into the given Hasher.

This method is meant as a convenience, but its implementation is also explicitly left unspecified. It isn’t guaranteed to be equivalent to repeated calls of hash and implementations of Hash should keep that in mind and call hash themselves if the slice isn’t treated as a whole unit in the PartialEq implementation.

For example, a VecDeque implementation might naïvely call as_slices and then hash_slice on each slice, but this is wrong since the two slices can change with a call to make_contiguous without affecting the PartialEq result. Since these slices aren’t treated as singular units, and instead part of a larger deque, this method cannot be used.

Examples
use std::hash::{DefaultHasher, Hash, Hasher};

let mut hasher = DefaultHasher::new();
let numbers = [6, 28, 496, 8128];
Hash::hash_slice(&numbers, &mut hasher);
println!("Hash is {:x}!", hasher.finish());

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

1.29.0 · Source

impl Hash for !

1.0.0 · Source

impl Hash for ()

Source

impl Hash for ATerm

Source

impl Hash for Alignment

Source

impl Hash for AsciiChar

Source

impl Hash for AttachmentSetupKey

Source

impl Hash for Attribute

Source

impl Hash for Attributes

Source

impl Hash for Authority

Case-insensitive hashing

Examples


let a: Authority = "HELLO.com".parse().unwrap();
let b: Authority = "hello.coM".parse().unwrap();

let mut s = DefaultHasher::new();
a.hash(&mut s);
let a = s.finish();

let mut s = DefaultHasher::new();
b.hash(&mut s);
let b = s.finish();

assert_eq!(a, b);
Source

impl Hash for B0

Source

impl Hash for B1

Source

impl Hash for BStr

Source

impl Hash for BString

Source

impl Hash for BidiClass

Source

impl Hash for zerocopy::byteorder::BigEndian

Source

impl Hash for byteorder::BigEndian

Source

impl Hash for Braced

Source

impl Hash for BufferFormat

Source

impl Hash for ByteStr

Source

impl Hash for ByteString

Source

impl Hash for Bytes

Source

impl Hash for BytesMut

1.64.0 · Source

impl Hash for CStr

1.64.0 · Source

impl Hash for CString

Source

impl Hash for CalendarAlgorithm

Source

impl Hash for CanonicalCombiningClass

Source

impl Hash for CharCase

Source

impl Hash for CharULE

Source

impl Hash for CollationCaseFirst

Source

impl Hash for CollationNumericOrdering

Source

impl Hash for CollationType

Source

impl Hash for Colons

Source

impl Hash for CommonVariantType

Source

impl Hash for ComponentRange

Source

impl Hash for CurrencyFormatStyle

Source

impl Hash for CurrencyType

Source

impl Hash for DataLocale

Source

impl Hash for DataMarkerAttributes

Source

impl Hash for DataMarkerId

Source

impl Hash for DataMarkerIdHash

Source

impl Hash for DataMarkerInfo

Source

impl Hash for time::date::Date

Source

impl Hash for Days

1.3.0 · Source

impl Hash for core::time::Duration

Source

impl Hash for time::duration::Duration

Source

impl Hash for EastAsianWidth

Source

impl Hash for EmojiPresentationStyle

Source

impl Hash for EmojiStatus

Source

impl Hash for Encoding

Source

impl Hash for Equal

Source

impl Hash for Errno

1.0.0 · Source

impl Hash for core::fmt::Error

Source

impl Hash for uuid::error::Error

1.0.0 · Source

impl Hash for ErrorKind

Source

impl Hash for ExtensionType

Source

impl Hash for Extensions

Source

impl Hash for Field

Source

impl Hash for FieldId

Source

impl Hash for FieldPath

Source

impl Hash for Fields

1.1.0 · Source

impl Hash for FileType

Source

impl Hash for Fingerprint

Source

impl Hash for FirstDay

Source

impl Hash for Fixed

Source

impl Hash for FixedOffset

Source

impl Hash for icu_properties::props::gc::GeneralCategory

Source

impl Hash for unicode_properties::tables::general_category::GeneralCategory

Source

impl Hash for GeneralCategoryGroup

Source

impl Hash for GeneralCategoryOutOfBoundsError

Source

impl Hash for Glob

Source

impl Hash for GraphemeClusterBreak

Source

impl Hash for Greater

Source

impl Hash for HalfMatch

Source

impl Hash for HangulSyllableType

Source

impl Hash for Hash

Source

impl Hash for HeaderName

Source

impl Hash for HeaderValue

Source

impl Hash for HijriCalendarAlgorithm

Source

impl Hash for HourCycle

Source

impl Hash for HttpDate

Source

impl Hash for Hyphenated

Source

impl Hash for tokio::runtime::task::id::Id

Source

impl Hash for tokio::runtime::id::Id

Source

impl Hash for tracing_core::span::Id

Source

impl Hash for Identifier

Source

impl Hash for Index8

Source

impl Hash for Index16

Source

impl Hash for Index32

Source

impl Hash for IndicConjunctBreak

Source

impl Hash for IndicSyllabicCategory

1.44.0 · Source

impl Hash for Infallible

Source

impl Hash for InsertError

1.8.0 · Source

impl Hash for std::time::Instant

Source

impl Hash for tokio::time::instant::Instant

1.55.0 · Source

impl Hash for IntErrorKind

Source

impl Hash for InternalFixed

Source

impl Hash for InternalNumeric

1.7.0 · Source

impl Hash for core::net::ip_addr::IpAddr

Source

impl Hash for rustls_pki_types::server_name::IpAddr

Source

impl Hash for IpAddrRange

Source

impl Hash for IpNet

Source

impl Hash for IpSubnets

1.0.0 · Source

impl Hash for core::net::ip_addr::Ipv4Addr

Source

impl Hash for rustls_pki_types::server_name::Ipv4Addr

Source

impl Hash for Ipv4AddrRange

Source

impl Hash for Ipv4Net

Source

impl Hash for Ipv4Subnets

1.0.0 · Source

impl Hash for core::net::ip_addr::Ipv6Addr

Source

impl Hash for rustls_pki_types::server_name::Ipv6Addr

Source

impl Hash for Ipv6AddrRange

Source

impl Hash for Ipv6MulticastScope

Source

impl Hash for Ipv6Net

Source

impl Hash for Ipv6Subnets

Source

impl Hash for IriSpec

Source

impl Hash for IsoWeek

Source

impl Hash for JoiningType

Source

impl Hash for icu_locale_core::extensions::transform::key::Key

Source

impl Hash for icu_locale_core::extensions::unicode::key::Key

Source

impl Hash for KeyPart

Source

impl Hash for KeyValue

Source

impl Hash for Keywords

Source

impl Hash for Language

Source

impl Hash for LanguageIdentifier

1.28.0 · Source

impl Hash for Layout

Source

impl Hash for LazyStateID

Source

impl Hash for Less

Source

impl Hash for tracing_core::metadata::Level

Source

impl Hash for log::Level

Source

impl Hash for tracing_core::metadata::LevelFilter

Source

impl Hash for log::LevelFilter

Source

impl Hash for LineBreak

Source

impl Hash for LineBreakStyle

Source

impl Hash for LineBreakWordHandling

Source

impl Hash for zerocopy::byteorder::LittleEndian

Source

impl Hash for byteorder::LittleEndian

Source

impl Hash for Locale

Source

impl Hash for LocalePreferences

Source

impl Hash for Locality

1.10.0 · Source

impl Hash for Location<'_>

Source

impl Hash for Map<String, Value>

Source

impl Hash for aho_corasick::util::search::Match

Source

impl Hash for regex_automata::util::search::Match

Source

impl Hash for MeasurementSystem

Source

impl Hash for MeasurementUnitOverride

Source

impl Hash for Method

Source

impl Hash for Mime

Source

impl Hash for chrono::month::Month

Source

impl Hash for time::month::Month

Source

impl Hash for Months

Source

impl Hash for NaiveDate

Source

impl Hash for NaiveDateDaysIterator

Source

impl Hash for NaiveDateTime

Source

impl Hash for NaiveDateWeeksIterator

Source

impl Hash for NaiveTime

Source

impl Hash for NaiveWeek

Source

impl Hash for hyper_util::client::legacy::connect::dns::Name

Source

impl Hash for NonMaxUsize

Source

impl Hash for NonNilUuid

Source

impl Hash for Number

Source

impl Hash for NumberingSystem

Source

impl Hash for Numeric

Source

impl Hash for OffsetDateTime

Source

impl Hash for OffsetFormat

Source

impl Hash for OffsetPrecision

Source

impl Hash for Oid

Source

impl Hash for OpaqueOrigin

1.0.0 · Source

impl Hash for core::cmp::Ordering

1.0.0 · Source

impl Hash for core::sync::atomic::Ordering

Source

impl Hash for Origin

1.0.0 · Source

impl Hash for OsStr

1.0.0 · Source

impl Hash for OsString

Source

impl Hash for Other

Source

impl Hash for OutOfRange

Source

impl Hash for Pad

Source

impl Hash for ParseError

Source

impl Hash for ParseErrorKind

Source

impl Hash for Parsed

1.0.0 · Source

impl Hash for Path

Source

impl Hash for PathAndQuery

1.0.0 · Source

impl Hash for PathBuf

Source

impl Hash for aho_corasick::util::primitives::PatternID

Source

impl Hash for regex_automata::util::primitives::PatternID

Source

impl Hash for PgInterval

Source

impl Hash for PgLQueryVariantFlag

1.33.0 · Source

impl Hash for PhantomPinned

Source

impl Hash for PollNext

Source

impl Hash for PotentialCodePoint

1.0.0 · Source

impl Hash for PrefixComponent<'_>

Source

impl Hash for PrimitiveDateTime

Source

impl Hash for Private

1.0.0 · Source

impl Hash for RangeFull

Source

impl Hash for RangeValue

Source

impl Hash for ReasonPhrase

Source

impl Hash for Region

Source

impl Hash for RegionOverride

Source

impl Hash for RegionalSubdivision

Source

impl Hash for ResourceIdentifier

Source

impl Hash for Scheme

Case-insensitive hashing

Source

impl Hash for icu_locale_core::subtags::script::Script

Source

impl Hash for icu_properties::props::Script

Source

impl Hash for SecondsFormat

Source

impl Hash for SentenceBreak

Source

impl Hash for SentenceBreakSupressions

Source

impl Hash for SigId

Source

impl Hash for SignalKind

Source

impl Hash for Simple

Source

impl Hash for SmallIndex

Source

impl Hash for SockAddr

1.0.0 · Source

impl Hash for SocketAddr

1.0.0 · Source

impl Hash for SocketAddrV4

1.0.0 · Source

impl Hash for SocketAddrV6

Source

impl Hash for recoco_core::prelude::Span

Source

impl Hash for aho_corasick::util::search::Span

Source

impl Hash for regex_automata::util::search::Span

Source

impl Hash for aho_corasick::util::primitives::StateID

Source

impl Hash for regex_automata::util::primitives::StateID

Source

impl Hash for StatusCode

1.0.0 · Source

impl Hash for String

Source

impl Hash for SubdivisionId

Source

impl Hash for SubdivisionSuffix

Source

impl Hash for icu_locale_core::extensions::private::other::Subtag

Source

impl Hash for icu_locale_core::subtags::Subtag

1.8.0 · Source

impl Hash for SystemTime

1.19.0 · Source

impl Hash for ThreadId

Source

impl Hash for Time

Source

impl Hash for TimeDelta

Source

impl Hash for TimeZoneShortId

Source

impl Hash for Timestamp

Source

impl Hash for Token

Source

impl Hash for Transform

Source

impl Hash for Transition

1.0.0 · Source

impl Hash for TypeId

Source

impl Hash for std::os::unix::net::ucred::UCred

Source

impl Hash for tokio::net::unix::ucred::UCred

Source

impl Hash for UStr

Source

impl Hash for UTerm

Source

impl Hash for Unicode

Source

impl Hash for UnixTime

Source

impl Hash for Uri

Source

impl Hash for UriSpec

Source

impl Hash for UriTemplateStr

Source

impl Hash for UriTemplateString

Source

impl Hash for Url

URLs hash like their serialization.

Source

impl Hash for Urn

Source

impl Hash for Utc

Source

impl Hash for UtcDateTime

Source

impl Hash for UtcOffset

Source

impl Hash for Uuid

Source

impl Hash for serde_json::value::Value

Source

impl Hash for icu_locale_core::extensions::transform::value::Value

Source

impl Hash for icu_locale_core::extensions::unicode::value::Value

Source

impl Hash for Variant

Source

impl Hash for Variants

Source

impl Hash for Version

Source

impl Hash for VerticalOrientation

Source

impl Hash for chrono::weekday::Weekday

Source

impl Hash for time::weekday::Weekday

Source

impl Hash for WeekdaySet

Source

impl Hash for WordBreak

Source

impl Hash for Yaml

Source

impl Hash for Z0

1.0.0 · Source

impl Hash for bool

1.0.0 · Source

impl Hash for char

1.0.0 · Source

impl Hash for i8

1.0.0 · Source

impl Hash for i16

1.0.0 · Source

impl Hash for i32

1.0.0 · Source

impl Hash for i64

1.0.0 · Source

impl Hash for i128

1.0.0 · Source

impl Hash for isize

Source

impl Hash for point_conversion_form_t

1.0.0 · Source

impl Hash for str

1.0.0 · Source

impl Hash for u8

1.0.0 · Source

impl Hash for u16

1.0.0 · Source

impl Hash for u32

1.0.0 · Source

impl Hash for u64

1.0.0 · Source

impl Hash for u128

1.0.0 · Source

impl Hash for usize

Source

impl<'a> Hash for AuthorityComponents<'a>

Source

impl<'a> Hash for CertificateDer<'a>

Source

impl<'a> Hash for CertificateRevocationListDer<'a>

Source

impl<'a> Hash for CertificateSigningRequestDer<'a>

1.0.0 · Source

impl<'a> Hash for Component<'a>

Source

impl<'a> Hash for Der<'a>

Source

impl<'a> Hash for DnsName<'a>

Source

impl<'a> Hash for EchConfigListBytes<'a>

Source

impl<'a> Hash for Item<'a>

Source

impl<'a> Hash for Metadata<'a>

Source

impl<'a> Hash for MetadataBuilder<'a>

Source

impl<'a> Hash for mime::Name<'a>

Source

impl<'a> Hash for PhantomContravariantLifetime<'a>

Source

impl<'a> Hash for PhantomCovariantLifetime<'a>

Source

impl<'a> Hash for PhantomInvariantLifetime<'a>

1.0.0 · Source

impl<'a> Hash for Prefix<'a>

Source

impl<'a> Hash for ServerName<'a>

Source

impl<'a> Hash for SubjectPublicKeyInfoDer<'a>

Source

impl<'a> Hash for TrustAnchor<'a>

Source

impl<'a> Hash for VarName<'a>

Source

impl<'r, R> Hash for UnwrapMut<'r, R>
where R: Hash + TryRngCore + ?Sized,

Source

impl<'s, T> Hash for SliceVec<'s, T>
where T: Hash,

Source

impl<A, B> Hash for EitherOrBoth<A, B>
where A: Hash, B: Hash,

Source

impl<A> Hash for tinyvec::arrayvec::ArrayVec<A>
where A: Array, <A as Array>::Item: Hash,

Source

impl<A> Hash for SmallVec<A>
where A: Array, <A as Array>::Item: Hash,

Source

impl<A> Hash for TinyVec<A>
where A: Array, <A as Array>::Item: Hash,

1.55.0 · Source

impl<B, C> Hash for ControlFlow<B, C>
where B: Hash, C: Hash,

1.0.0 · Source

impl<B> Hash for Cow<'_, B>
where B: Hash + ToOwned + ?Sized,

Source

impl<DataStruct> Hash for ErasedMarker<DataStruct>
where DataStruct: Hash + for<'a> Yokeable<'a>,

Source

impl<Dyn> Hash for DynMetadata<Dyn>
where Dyn: ?Sized,

1.4.0 · Source

impl<F> Hash for F
where F: FnPtr,

1.0.0 · Source

impl<Idx> Hash for core::ops::range::Range<Idx>
where Idx: Hash,

1.96.0 · Source

impl<Idx> Hash for core::range::Range<Idx>
where Idx: Hash,

1.0.0 · Source

impl<Idx> Hash for core::ops::range::RangeFrom<Idx>
where Idx: Hash,

1.96.0 · Source

impl<Idx> Hash for core::range::RangeFrom<Idx>
where Idx: Hash,

1.26.0 · Source

impl<Idx> Hash for core::ops::range::RangeInclusive<Idx>
where Idx: Hash,

1.95.0 · Source

impl<Idx> Hash for core::range::RangeInclusive<Idx>
where Idx: Hash,

1.0.0 · Source

impl<Idx> Hash for RangeTo<Idx>
where Idx: Hash,

1.26.0 · Source

impl<Idx> Hash for core::ops::range::RangeToInclusive<Idx>
where Idx: Hash,

1.96.0 · Source

impl<Idx> Hash for core::range::RangeToInclusive<Idx>
where Idx: Hash,

1.0.0 · Source

impl<K, V, A> Hash for BTreeMap<K, V, A>
where K: Hash, V: Hash, A: Allocator + Clone,

Source

impl<K, V, S> Hash for hashlink::linked_hash_map::LinkedHashMap<K, V, S>
where K: Hash + Eq, V: Hash, S: BuildHasher,

Source

impl<K, V, S> Hash for hashlink::linked_hash_map::LinkedHashMap<K, V, S>
where K: Hash + Eq, V: Hash, S: BuildHasher,

Source

impl<K, V, S> Hash for LiteMap<K, V, S>
where K: Hash + ?Sized, V: Hash + ?Sized, S: Hash,

Source

impl<K, V> Hash for indexmap::map::slice::Slice<K, V>
where K: Hash, V: Hash,

Source

impl<L, R> Hash for Either<L, R>
where L: Hash, R: Hash,

Source

impl<O> Hash for F32<O>
where O: Hash,

Source

impl<O> Hash for F64<O>
where O: Hash,

Source

impl<O> Hash for I16<O>
where O: Hash,

Source

impl<O> Hash for I32<O>
where O: Hash,

Source

impl<O> Hash for I64<O>
where O: Hash,

Source

impl<O> Hash for I128<O>
where O: Hash,

Source

impl<O> Hash for Isize<O>
where O: Hash,

Source

impl<O> Hash for U16<O>
where O: Hash,

Source

impl<O> Hash for U32<O>
where O: Hash,

Source

impl<O> Hash for U64<O>
where O: Hash,

Source

impl<O> Hash for U128<O>
where O: Hash,

Source

impl<O> Hash for Usize<O>
where O: Hash,

1.41.0 · Source

impl<Ptr> Hash for Pin<Ptr>
where Ptr: Deref, <Ptr as Deref>::Target: Hash,

Source

impl<R> Hash for UnwrapErr<R>
where R: Hash + TryRngCore,

Source

impl<S> Hash for Host<S>
where S: Hash,

Source

impl<S> Hash for RiAbsoluteStr<S>
where S: Spec,

Source

impl<S> Hash for RiAbsoluteString<S>
where S: Spec,

Source

impl<S> Hash for RiFragmentStr<S>
where S: Spec,

Source

impl<S> Hash for RiFragmentString<S>
where S: Spec,

Source

impl<S> Hash for RiQueryStr<S>
where S: Spec,

Source

impl<S> Hash for RiQueryString<S>
where S: Spec,

Source

impl<S> Hash for RiReferenceStr<S>
where S: Spec,

Source

impl<S> Hash for RiReferenceString<S>
where S: Spec,

Source

impl<S> Hash for RiRelativeStr<S>
where S: Spec,

Source

impl<S> Hash for RiRelativeString<S>
where S: Spec,

Source

impl<S> Hash for RiStr<S>
where S: Spec,

Source

impl<S> Hash for RiString<S>
where S: Spec,

Source

impl<Storage> Hash for __BindgenBitfieldUnit<Storage>
where Storage: Hash,

Source

impl<Str> Hash for Encoded<Str>
where Str: Hash,

1.0.0 · Source

impl<T, A> Hash for Arc<T, A>
where T: Hash + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Hash for BTreeSet<T, A>
where T: Hash, A: Allocator + Clone,

1.0.0 · Source

impl<T, A> Hash for alloc::boxed::Box<T, A>
where T: Hash + ?Sized, A: Allocator,

Source

impl<T, A> Hash for allocator_api2::stable::boxed::Box<T, A>
where T: Hash + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Hash for LinkedList<T, A>
where T: Hash, A: Allocator,

1.0.0 · Source

impl<T, A> Hash for Rc<T, A>
where T: Hash + ?Sized, A: Allocator,

Source

impl<T, A> Hash for UniqueArc<T, A>
where T: Hash + ?Sized, A: Allocator,

Source

impl<T, A> Hash for UniqueRc<T, A>
where T: Hash + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Hash for alloc::vec::Vec<T, A>
where T: Hash, A: Allocator,

The hash of a vector is the same as that of the corresponding slice, as required by the core::borrow::Borrow implementation.

use std::hash::BuildHasher;

let b = std::hash::RandomState::new();
let v: Vec<u8> = vec![0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(v), b.hash_one(s));
Source

impl<T, A> Hash for allocator_api2::stable::vec::Vec<T, A>
where T: Hash, A: Allocator,

The hash of a vector is the same as that of the corresponding slice, as required by the core::borrow::Borrow implementation.

#![feature(build_hasher_simple_hash_one)]
use std::hash::BuildHasher;

let b = std::collections::hash_map::RandomState::new();
let v: Vec<u8> = vec![0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(v), b.hash_one(s));
1.0.0 · Source

impl<T, A> Hash for VecDeque<T, A>
where T: Hash, A: Allocator,

1.0.0 · Source

impl<T, E> Hash for Result<T, E>
where T: Hash, E: Hash,

Source

impl<T, N> Hash for GenericArray<T, N>
where T: Hash, N: ArrayLength<T>,

Source

impl<T, S> Hash for hashlink::linked_hash_set::LinkedHashSet<T, S>
where T: Eq + Hash, S: BuildHasher,

Source

impl<T, S> Hash for hashlink::linked_hash_set::LinkedHashSet<T, S>
where T: Eq + Hash, S: BuildHasher,

Source

impl<T, const CAP: usize, B> Hash for ArrayDeque<T, CAP, B>
where B: Behavior, T: Hash,

Source

impl<T, const CAP: usize> Hash for arrayvec::arrayvec::ArrayVec<T, CAP>
where T: Hash,

Source

impl<T, const N: usize> Hash for Simd<T, N>
where T: SimdElement + Hash,

1.0.0 · Source

impl<T, const N: usize> Hash for [T; N]
where T: Hash,

The hash of an array is the same as that of the corresponding slice, as required by the Borrow implementation.

use std::hash::BuildHasher;

let b = std::hash::RandomState::new();
let a: [u8; 3] = [0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(a), b.hash_one(s));
Source

impl<T, const VARIANT: u32, const FIELD: u32> Hash for FieldRepresentingType<T, VARIANT, FIELD>
where T: ?Sized,

Source

impl<T: Hash> Hash for NamedSpec<T>

1.0.0 · Source

impl<T> Hash for &T
where T: Hash + ?Sized,

1.0.0 · Source

impl<T> Hash for &mut T
where T: Hash + ?Sized,

1.0.0 · Source

impl<T> Hash for (T₁, T₂, …, Tₙ)
where T: Hash,

This trait is implemented for tuples up to twelve items long.

1.0.0 · Source

impl<T> Hash for *const T
where T: ?Sized,

1.0.0 · Source

impl<T> Hash for *mut T
where T: ?Sized,

Source

impl<T> Hash for AllowStdIo<T>
where T: Hash,

Source

impl<T> Hash for AuthEntryReference<T>

1.17.0 · Source

impl<T> Hash for Bound<T>
where T: Hash,

Source

impl<T> Hash for CachePadded<T>
where T: Hash,

1.21.0 · Source

impl<T> Hash for Discriminant<T>

Source

impl<T> Hash for Json<T>
where T: Hash + ?Sized,

Source

impl<T> Hash for LocalResult<T>
where T: Hash,

1.20.0 · Source

impl<T> Hash for ManuallyDrop<T>
where T: Hash + ?Sized,

1.25.0 · Source

impl<T> Hash for NonNull<T>
where T: ?Sized,

1.28.0 · Source

impl<T> Hash for NonZero<T>

1.0.0 · Source

impl<T> Hash for Option<T>
where T: Hash,

Source

impl<T> Hash for PhantomContravariant<T>
where T: ?Sized,

Source

impl<T> Hash for PhantomCovariant<T>
where T: ?Sized,

1.0.0 · Source

impl<T> Hash for PhantomData<T>
where T: ?Sized,

Source

impl<T> Hash for PhantomInvariant<T>
where T: ?Sized,

1.36.0 · Source

impl<T> Hash for Poll<T>
where T: Hash,

1.19.0 · Source

impl<T> Hash for Reverse<T>
where T: Hash,

1.74.0 · Source

impl<T> Hash for Saturating<T>
where T: Hash,

Source

impl<T> Hash for indexmap::set::slice::Slice<T>
where T: Hash,

Source

impl<T> Hash for SyncView<T>
where T: Sync + Hash + ?Sized,

Source

impl<T> Hash for TryWriteableInfallibleAsWriteable<T>
where T: Hash,

Source

impl<T> Hash for Unalign<T>
where T: Unaligned + Hash,

1.0.0 · Source

impl<T> Hash for Wrapping<T>
where T: Hash,

Source

impl<T> Hash for WriteableAsTryWriteableInfallible<T>
where T: Hash,

1.0.0 · Source

impl<T> Hash for [T]
where T: Hash,

Source

impl<Tz> Hash for chrono::date::Date<Tz>
where Tz: TimeZone,

Source

impl<Tz> Hash for DateTime<Tz>
where Tz: TimeZone,

Source

impl<U, B> Hash for UInt<U, B>
where U: Hash, B: Hash,

Source

impl<U, const N: usize> Hash for NichedOption<U, N>
where U: Hash,

Source

impl<U> Hash for NInt<U>
where U: Hash + Unsigned + NonZero,

Source

impl<U> Hash for PInt<U>
where U: Hash + Unsigned + NonZero,

Source

impl<V, A> Hash for TArr<V, A>
where V: Hash, A: Hash,

Source

impl<Y, R> Hash for CoroutineState<Y, R>
where Y: Hash, R: Hash,

Source

impl<const CAP: usize> Hash for ArrayString<CAP>

Source

impl<const MIN: i8, const MAX: i8> Hash for OptionRangedI8<MIN, MAX>

Source

impl<const MIN: i8, const MAX: i8> Hash for RangedI8<MIN, MAX>

Source

impl<const MIN: i16, const MAX: i16> Hash for OptionRangedI16<MIN, MAX>

Source

impl<const MIN: i16, const MAX: i16> Hash for RangedI16<MIN, MAX>

Source

impl<const MIN: i32, const MAX: i32> Hash for OptionRangedI32<MIN, MAX>

Source

impl<const MIN: i32, const MAX: i32> Hash for RangedI32<MIN, MAX>

Source

impl<const MIN: i64, const MAX: i64> Hash for OptionRangedI64<MIN, MAX>

Source

impl<const MIN: i64, const MAX: i64> Hash for RangedI64<MIN, MAX>

Source

impl<const MIN: i128, const MAX: i128> Hash for OptionRangedI128<MIN, MAX>

Source

impl<const MIN: i128, const MAX: i128> Hash for RangedI128<MIN, MAX>

Source

impl<const MIN: isize, const MAX: isize> Hash for OptionRangedIsize<MIN, MAX>

Source

impl<const MIN: isize, const MAX: isize> Hash for RangedIsize<MIN, MAX>

Source

impl<const MIN: u8, const MAX: u8> Hash for OptionRangedU8<MIN, MAX>

Source

impl<const MIN: u8, const MAX: u8> Hash for RangedU8<MIN, MAX>

Source

impl<const MIN: u16, const MAX: u16> Hash for OptionRangedU16<MIN, MAX>

Source

impl<const MIN: u16, const MAX: u16> Hash for RangedU16<MIN, MAX>

Source

impl<const MIN: u32, const MAX: u32> Hash for OptionRangedU32<MIN, MAX>

Source

impl<const MIN: u32, const MAX: u32> Hash for RangedU32<MIN, MAX>

Source

impl<const MIN: u64, const MAX: u64> Hash for OptionRangedU64<MIN, MAX>

Source

impl<const MIN: u64, const MAX: u64> Hash for RangedU64<MIN, MAX>

Source

impl<const MIN: u128, const MAX: u128> Hash for OptionRangedU128<MIN, MAX>

Source

impl<const MIN: u128, const MAX: u128> Hash for RangedU128<MIN, MAX>

Source

impl<const MIN: usize, const MAX: usize> Hash for OptionRangedUsize<MIN, MAX>

Source

impl<const MIN: usize, const MAX: usize> Hash for RangedUsize<MIN, MAX>

Source

impl<const N: usize> Hash for RawBytesULE<N>

Source

impl<const N: usize> Hash for TinyAsciiStr<N>

Source

impl<const SIZE: usize> Hash for WriteBuffer<SIZE>